@@ -1,17 +1,11 @@
-from typing import Dict, List
+from typing import Dict, List, TYPE_CHECKING
 
-from lionwebpython.api.composite_classifier_instance_resolver import \
-    CompositeClassifierInstanceResolver
-from lionwebpython.api.local_classifier_instance_resolver import \
-    LocalClassifierInstanceResolver
 from lionwebpython.language.data_type import DataType
 from lionwebpython.lionweb_version import LionWebVersion
 from lionwebpython.model import ClassifierInstance
-from lionwebpython.model.annotation_instance import AnnotationInstance
 from lionwebpython.model.classifier_instance_utils import \
     ClassifierInstanceUtils
 from lionwebpython.model.has_settable_parent import HasSettableParent
-from lionwebpython.model.impl.proxy_node import ProxyNode
 from lionwebpython.serialization.classifier_resolver import ClassifierResolver
 from lionwebpython.serialization.data.metapointer import MetaPointer
 from lionwebpython.serialization.data.serialized_chunk import SerializedChunk
@@ -29,13 +23,13 @@ from lionwebpython.serialization.deserialization_exception import \
 from lionwebpython.serialization.deserialization_status import \
     DeserializationStatus
 from lionwebpython.serialization.instantiator import Instantiator
-from lionwebpython.serialization.map_based_resolver import MapBasedResolver
-from lionwebpython.serialization.node_populator import NodePopulator
 from lionwebpython.serialization.primitives_values_serialization import \
     PrimitiveValuesSerialization
 from lionwebpython.serialization.unavailable_node_policy import \
     UnavailableNodePolicy
 
+if TYPE_CHECKING:
+    from lionwebpython.model.annotation_instance import AnnotationInstance
 
 class AbstractSerialization:
 
@@ -44,6 +38,8 @@ class AbstractSerialization:
     def __init__(
         self, lionweb_version: LionWebVersion = LionWebVersion.current_version()
     ):
+        from lionwebpython.api.local_classifier_instance_resolver import \
+            LocalClassifierInstanceResolver
         self.lion_web_version = lionweb_version
         self.classifier_resolver = ClassifierResolver()
         self.instantiator = Instantiator()
@@ -162,7 +158,7 @@ class AbstractSerialization:
         return serialized_instance
 
     def serialize_annotation_instance(
-        self, annotation_instance: AnnotationInstance
+        self, annotation_instance: 'AnnotationInstance'
     ) -> SerializedClassifierInstance:
         if annotation_instance is None:
             raise ValueError("AnnotationInstance should not be null")
@@ -174,9 +170,7 @@ class AbstractSerialization:
             ),
         )
         parent = annotation_instance.get_parent()
-        serialized_classifier_instance.parent_node_id = (
-            parent.id if parent else None
-        )
+        serialized_classifier_instance.parent_node_id = parent.id if parent else None
         self._serialize_properties(annotation_instance, serialized_classifier_instance)
         self._serialize_containments(
             annotation_instance, serialized_classifier_instance
@@ -238,10 +232,7 @@ class AbstractSerialization:
                 raise ValueError()
             containment_value = SerializedContainmentValue(
                 MetaPointer.from_keyed(containment, language),
-                [
-                    child.id
-                    for child in classifier_instance.get_children(containment)
-                ],
+                [child.id for child in classifier_instance.get_children(containment)],
             )
             serialized_classifier_instance.add_containment_value(containment_value)
 
@@ -303,6 +294,13 @@ class AbstractSerialization:
         lion_web_version: LionWebVersion,
         serialized_classifier_instances: List[SerializedClassifierInstance],
     ) -> (List)[ClassifierInstance]:
+        from lionwebpython.api.composite_classifier_instance_resolver import \
+            CompositeClassifierInstanceResolver
+        from lionwebpython.model.annotation_instance import AnnotationInstance
+        from lionwebpython.model.impl.proxy_node import ProxyNode
+        from lionwebpython.serialization.map_based_resolver import MapBasedResolver
+        from lionwebpython.serialization.node_populator import NodePopulator
+
         if lion_web_version is None:
             raise ValueError("lion_web_version should not be null")
 
